package com.plugin.flutterpluginsystem

import android.app.Activity
import android.app.ActivityManager
import android.content.ComponentName
import android.content.Context
import android.content.Intent
import android.util.Log
import android.widget.Toast
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.net.NetworkInterface
import java.util.*

class FlutterPluginSystemPlugin(activity: Activity) : MethodCallHandler {
  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "flutter_plugin_system")
      channel.setMethodCallHandler(FlutterPluginSystemPlugin(registrar.activity()))
    }
  }
   private var mActivity: Activity = activity

    override fun onMethodCall(call: MethodCall, result: Result) {
    when {
        call.method == "isVpnUsed" -> isVpnUsed(result)
        call.method == "getAppPakageName" -> getAppPakageName(result)
        call.method == "getCacheSize" -> result.success(DataCleanManager.getTotalCacheSize(mActivity))
        call.method == "clearCache" -> {
          DataCleanManager.clearAllCache(mActivity)
          result.success(true)
        }
        call.method == "lunchWebView" -> lunchWebView(call.arguments as List<String>)
        else -> result.notImplemented()
    }
  }

    private fun lunchWebView(arguments:List<String>) {
        Toast.makeText(mActivity,"${arguments[0]}----${arguments[1]}",Toast.LENGTH_SHORT).show()
//        val intent=Intent()
//        intent.component=ComponentName(mActivity,arguments[1])
//        intent.putExtra("extra_url",arguments[0])
//        mActivity.startActivity(intent)
    }
  private fun getAppPakageName(result: MethodChannel.Result) {
    //当前应用pid
    val pid = android.os.Process.myPid()
    //任务管理类
    val manager = mActivity.getSystemService(Context.ACTIVITY_SERVICE) as ActivityManager
    //遍历所有应用
    val infos = manager.runningAppProcesses
    for (info in infos) {
      if (info.pid == pid)
      //得到当前应用
        result.success(info.processName) //返回包名
    }
  }
  private fun isVpnUsed(result: MethodChannel.Result?) {
    var isUsedVpn = false
    try {
      val niList = NetworkInterface.getNetworkInterfaces()
      if (niList != null) {
        for (intf in Collections.list(niList)) {
          if (!intf.isUp || intf.interfaceAddresses.size == 0) {
            continue
          }
          if ("tun0" == intf.name || "ppp0" == intf.name) {
            Log.v("│ -->", "│ --> isVpnUsed() NetworkInterface Name: " + intf.name)
            isUsedVpn = true // The VPN is up
          }
        }
      }
      result!!.success(isUsedVpn)
    } catch (e: Throwable) {
      result!!.error("检查vpn发生异常", "${e.message}", isUsedVpn)
      e.printStackTrace()
    }
  }
}
